@@ -10,9 +10,13 @@ from . import utils
 from ._version import __version__
 from .client import Fiddler, PredictionEventBundle
 from .core_objects import (
+    BatchPublishType,
     Column,
     DatasetInfo,
     DataType,
+    ExplanationMethod,
+    FiddlerPublishSchema,
+    FiddlerTimestamp,
     MLFlowParams,
     ModelDeploymentParams,
     ModelInfo,
@@ -21,25 +25,25 @@ from .core_objects import (
 )
 from .fiddler_api import FiddlerApi
 from .utils import ColorLogger
-from .validator import (
-    PackageValidator,
-    ValidationChainSettings,
-    ValidationModule,
-)
+from .validator import PackageValidator, ValidationChainSettings, ValidationModule
 
 __all__ = [
     '__version__',
+    'BatchPublishType',
     'Column',
     'ColorLogger',
     'DatasetInfo',
     'DataType',
     'Fiddler',
     'FiddlerApi',
+    'FiddlerTimestamp',
+    'FiddlerPublishSchema',
     'MLFlowParams',
     'ModelDeploymentParams',
     'ModelInfo',
     'ModelInputType',
     'ModelTask',
+    'ExplanationMethod',
     'PredictionEventBundle',
     'PackageValidator',
     'ValidationChainSettings',
